@@ -149,21 +149,43 @@ void BattleFieldView::refresh()
     }
 }
 
-void BattleFieldView::setPreview(const QPointF& pos, Ship* ship)
+void BattleFieldView::setPreview(const QPoint & pos)
 {
-    if (!m_preview.sprite) {
-        m_preview.ship = ship;
-        m_preview.sprite = m_factory.createShip(ship);
-        kDebug() << "created preview: dir =" << ship->direction();
-        m_preview.sprite->setOpacity(PREVIEW_OPACITY);
-        scene()->addItem(m_preview.sprite);
-        m_preview.sprite->stackBefore(m_screen);
+    if (!m_delegate) {
+        return;
     }
-    
-    m_preview.pos = m_renderer->toLogical(pos);
+    Ship * ship = m_delegate->nextShip();
+
+    if (!ship) {
+        return;
+    }
+
+    loadPreviewSprite(ship);
+    Coord coordinate = m_renderer->toLogical(pos);
+
+    if (m_delegate->canAddShip(m_player, coordinate)) {
+        m_preview.sprite->turnGreen();
+    } else {
+        m_preview.sprite->turnRed();
+    }
+
+    QPointF scenePos = mapToScene(pos);
+    m_preview.pos = m_renderer->toLogical(scenePos);
     m_preview.sprite->setPos(m_renderer->toReal(m_preview.pos));
 }
 
+void BattleFieldView::loadPreviewSprite(Ship * ship)
+{
+    if (m_preview.ship) {
+        return;
+    }
+
+    m_preview.ship      = ship;
+    m_preview.sprite    = m_factory.createShip(ship);
+
+    m_preview.sprite->setOpacity(PREVIEW_OPACITY);
+    scene()->addItem(m_preview.sprite);
+}
 void BattleFieldView::cancelPreview()
 {
     delete m_preview.sprite;
@@ -174,7 +196,6 @@ void BattleFieldView::cancelPreview()
 void BattleFieldView::addSprite(const Coord& c, Sprite* sprite)
 {
     m_sprites.insert(c, sprite);
-    
     sprite->setPos(m_renderer->toReal(c));
     scene()->addItem(sprite);
 }
@@ -182,17 +203,21 @@ void BattleFieldView::addSprite(const Coord& c, Sprite* sprite)
 void BattleFieldView::add(Ship* ship)
 {
     Sprite* sprite = m_factory.createShip(ship);
+    sprite->setZValue(BACKGROUND);
     addSprite(ship->position(), sprite);
     
     // fading preview in
-    Animation* a = new FadeAnimation(sprite, PREVIEW_OPACITY, 1, 1000);
-    Animator::instance()->add(a);
+    if (ship->alive()) {
+        Animation* a = new FadeAnimation(sprite, PREVIEW_OPACITY, 1, 1000);
+        Animator::instance()->add(a);
+    }
 
     if (ship == m_preview.ship) {
         cancelPreview();
     }
     else if (!ship->alive()) {
-        Animation* a = new FadeAnimation(sprite, 0, 1, 1000);
+        sprite->setZValue(BACKGROUND);
+        Animation* a = new FadeAnimation(sprite, 0, 0.5, 1000);
         Animator::instance()->add(a);
     }
 }
@@ -200,7 +225,6 @@ void BattleFieldView::add(Ship* ship)
 void BattleFieldView::sink(Ship* ship)
 {
     m_last_hit = 0;
-    Sprite* ship_sprite = 0;
     
     Coord p = ship->position();
     for (unsigned int i = 0; 
@@ -208,26 +232,22 @@ void BattleFieldView::sink(Ship* ship)
          i++, p += ship->increment()) {
         foreach (Sprite* s, m_sprites.values(p)) {
             if (s->spriteKey().startsWith("ship")) {
-                ship_sprite = s;
-            }
-            else if (s->spriteKey().startsWith("hit")) {
-                s->setSpriteKey("hit-end");
-                s->refresh(m_renderer);
                 s->setZValue(BACKGROUND);
                 s->setOpacity(0.5);
             }
+            else if (s->spriteKey().startsWith("hit")) {
+                s->setSpriteKey("hit-end");
+            }
         }
     }
-    if (ship_sprite) {
-        ship_sprite->stackBefore(m_background);
-    }
 }
 
 void BattleFieldView::hit(const Coord& c)
 {
     removeImpact();
     m_last_hit = m_factory.createHit();
-    m_last_hit->setZValue(BACKGROUND);
+    m_last_hit->setZValue(FOREGROUND);
+    m_last_hit->setOpacity(1.0);
     addSprite(c, m_last_hit);
 }
 
@@ -235,7 +255,8 @@ void BattleFieldView::miss(const Coord& c)
 {
     removeImpact();
     m_impact = m_factory.createImpact();
-    m_impact->setZValue(BACKGROUND);
+    m_impact->setZValue(FOREGROUND);
+    m_impact->setOpacity(1.0);
     addSprite(c, m_impact);
 }
 
@@ -254,13 +275,15 @@ void BattleFieldView::removeImpact() {
 
 void BattleFieldView::clear()
 {
+    // fixes a crash when the ships can not be placed.
+    Animator::instance()->stop();
     delete m_preview.sprite;
     m_preview.sprite = 0;
     m_preview.ship = 0;
     
     m_impact = 0;
     m_last_hit = 0;
-    
+
     qDeleteAll(m_sprites);
     m_sprites.clear();
 }
@@ -281,11 +304,7 @@ void BattleFieldView::mousePressEvent(QMouseEvent *ev)
     else if (ev->button() == Qt::RightButton && m_delegate)
     {
         m_delegate->changeDirection(m_player);
-
-        Coord c = m_renderer->toLogical(ev->pos());
-
-        if(Ship *ship = m_delegate->canAddShip(m_player, c))
-            setPreview(mapToScene(ev->pos()), ship);
+        setPreview(ev->pos());
     }
 }
 
@@ -313,10 +332,7 @@ void BattleFieldView::mouseMoveEvent(QMouseEvent *ev)
     else
     {
         cancelPreview();
-        Coord c = m_renderer->toLogical(ev->pos());
-
-        if(Ship *ship = m_delegate->canAddShip(m_player, c))
-            setPreview(mapToScene(ev->pos()), ship);
+        setPreview(ev->pos());
     }
 }
 
@@ -344,4 +360,4 @@ void BattleFieldView::setPlayer(Sea::Player player)
     m_player = player;
 }
 
-const qreal BattleFieldView::PREVIEW_OPACITY = 0.5;
+const qreal BattleFieldView::PREVIEW_OPACITY = 0.7;
