@@ -18,6 +18,7 @@
 #include <KLocale>
 #include <KMessageBox>
 #include <KScoreDialog>
+#include <KDebug>
 
 #include "aientity.h"
 #include "audioplayer.h"
@@ -67,7 +68,12 @@ PlayField::~PlayField()
 
 Controller* PlayField::createController()
 {
-    Controller* controller = new Controller(this, m_player, Settings::adjacentShips());
+    // The client or server will overwrite this default configuration when 
+    // the network messages are interchanged
+    m_battle_ships_configuration = Settings::severalShips() ? 
+    BattleShipsConfiguration::defaultMultipleShipsConfiguration(Settings::adjacentShips()):
+    BattleShipsConfiguration::defaultSingleShipsConfiguration(Settings::adjacentShips());
+    Controller* controller = new Controller(this, m_player, m_battle_ships_configuration);
     connect(controller, SIGNAL(gameOver(Sea::Player)),
             this, SLOT(gameOver(Sea::Player)));
     connect(controller, SIGNAL(restartRequested()),
@@ -80,6 +86,10 @@ Controller* PlayField::createController()
             this, SLOT(changeTurn(int)));
     connect(controller, SIGNAL(playerReady(int)),
             this, SLOT(playerReady(int)));
+    connect(controller, SIGNAL(restartPlacingShips(Sea::Player)),
+            this, SLOT(restartPlacingShips(Sea::Player)));
+    connect(controller, SIGNAL(startPlacingShips(int)),
+            this, SLOT(startPlacingShips()));
 
     return controller;
 }
@@ -105,11 +115,13 @@ void PlayField::resetupController(bool ask)
     Entity* old_opponent = m_controller->findEntity(Sea::Player(1));
     if (old_opponent) {
         old_opponent->setParent(0);
-    }    
+    }
+    BattleShipsConfiguration oldBSC=m_controller->getBattleShipsConfiguration();
     delete m_controller;
 
     // create new controller
     m_controller = createController();
+    m_controller->setBattleShipsConfiguration(oldBSC);
     m_menu->setupController(m_controller, old_opponent, 
         m_seaView, m_chat, ask);
     delete old_opponent;
@@ -138,6 +150,7 @@ void PlayField::newGame()
     
     m_menu = new SimpleMenu(this, m_seaView->screen(Sea::Player(0)));
     connect(m_menu, SIGNAL(done()), this, SLOT(setupController()));
+    m_status_bar->showMessage(QLatin1String(""));
     emit welcomeScreen();
 }
 
@@ -145,7 +158,8 @@ void PlayField::restart(bool ask)
 {
     Animator::instance()->restart();
     m_seaView->clear();
-    resetupController(ask);
+    startGame();
+    m_controller->restart(ask);
 }
 
 
@@ -236,6 +250,12 @@ void PlayField::toggleAdjacent(bool enable)
     Settings::self()->writeConfig();
 }
 
+void PlayField::toggleMultiple(bool enable)
+{
+    Settings::setSeveralShips(enable);
+    Settings::self()->writeConfig();
+}
+
 void PlayField::restartRequested()
 {
     int ans = KMessageBox::questionYesNo(this, i18n("Restart game"),
@@ -248,7 +268,7 @@ void PlayField::restartRequested()
 void PlayField::setCompatibility(int level)
 {
     if (level == Entity::COMPAT_KBS3) {
-        KMessageBox::information(this, i18n("Your opponent is using a pre-KDE4 version of Naval Battle. Note that, according to the rules enforced by old clients, ships cannot be placed adjacent to one another."));
+        KMessageBox::information(this, i18n("Your opponent is using a pre-KDE4 version of Naval Battle. Note that, according to the rules enforced by old clients, ships cannot be placed adjacent to one another and only one ship of each size is allowed."));
     }
 }
 
@@ -289,8 +309,30 @@ void PlayField::startGame()
 {
     //the game has a fixed difficulty level only if there is an AI
     Kg::difficulty()->setGameRunning(m_controller->hasAI());
-    m_status_bar->showMessage(i18n("Place your ships. Use the right mouse button to rotate them."));
-    emit startingGame();
+    startPlacingShips();
+    emit placeShips();
+}
+
+void PlayField::startPlacingShips()
+{
+    m_status_bar->showMessage(i18n("Place your %1 ships. Use the right mouse button to rotate them.", m_battle_ships_configuration.totalNumberOfShipsToPlay()));
+}
+
+
+void PlayField::restartPlacingShips(Sea::Player player)
+{
+    m_status_bar->showMessage(i18n("You can't place your remaining ships."));
+    KMessageBox restartYesNo;
+    KGuiItem buttonRestart=KStandardGuiItem::yes(); buttonRestart.setText(i18n("Restart"));
+    KGuiItem buttonAbort=KStandardGuiItem::no(); buttonAbort.setText(i18n("Abort"));
+    int res=restartYesNo.warningYesNo(this, i18n("You can't place your remaining ships. Please restart placing ships or abort game"), i18n("Restart placing ships"), buttonRestart, buttonAbort);
+    if (res == KMessageBox::Yes) {
+        startPlacingShips();
+        m_controller->notifyRestartPlacingShips(player);
+    }
+    else {
+        newGame();
+    }
 }
 
 
