@@ -13,6 +13,7 @@
 #include <QWidget>
 #include <KgDifficulty>
 #include "sea.h"
+#include "ships.h"
 
 class SeaView;
 class Controller;
@@ -31,6 +32,7 @@ Q_OBJECT
     SimpleMenu* m_menu;
     QStatusBar* m_status_bar;
     bool m_show_endofgame_message;
+    BattleShipsConfiguration m_battle_ships_configuration;
 
     void startGame();
     void endGame();
@@ -51,13 +53,16 @@ public slots:
     void changeNick();
     void toggleSounds(bool);
     void toggleAdjacent(bool);
+    void toggleMultiple(bool);
     void restartRequested();
+    void startPlacingShips();
+    void restartPlacingShips(Sea::Player player);
     void setCompatibility(int);
     void updateNick(int, const QString&);
     void changeTurn(int);
     void playerReady(int);
     void levelChanged();
-    
+
     void auxMenuDone();
     void localGame();
     void createServer();
@@ -68,8 +73,9 @@ public slots:
     void toggleRightGrid(bool show);
 signals:
     void gameFinished();
+    void abortGame(Sea::Player player);
     void welcomeScreen();
-    void startingGame();
+    void placeShips();
 };
 
 #endif // PLAYFIELD_H
