@@ -10,19 +10,22 @@
 #include "sea.h"
 #include "battlefield.h"
 
-Sea::Sea(QObject* parent, const Coord& size, const bool allow_adjacent_ships)
+Sea::Sea(QObject* parent, const BattleShipsConfiguration& battleShipsConfiguration)
 : QObject(parent)
-, m_size(size)
+, m_size(Coord(battleShipsConfiguration.boardWidth(), battleShipsConfiguration.boardHeight()))
 , m_turn(PLAYER_A)
 , m_status(PLACING_SHIPS)
-, m_allow_adjacent_ships(allow_adjacent_ships)
+, m_battle_ships_configuration(battleShipsConfiguration)
 {
-    m_fields[0] = new BattleField(this, m_size);
-    m_fields[1] = new BattleField(this, m_size);
+    m_fields[0] = new BattleField(this, m_size, battleShipsConfiguration.isAllowedAdjacentShips());
+    m_fields[1] = new BattleField(this, m_size, battleShipsConfiguration.isAllowedAdjacentShips());
 }
 
 Sea::~Sea()
 {
+    m_enemyShips.clear();
+    m_myShips.clear();
+
 	delete m_fields[0];
 	delete m_fields[1];
 }
@@ -35,6 +38,28 @@ bool Sea::canAddShip(Player p, const Coord& pos, int size, Ship::Direction direc
     return m_fields[p]->canAddShip(pos, size, direction);
 }
 
+bool Sea::canAddShipOfSize(Player p, int size) const
+{
+    if (m_status != PLACING_SHIPS) {
+        return false;
+    }
+    return m_fields[p]->canAddShipOfSize(size);
+}
+
+void Sea::clear(Sea::Player p)
+{
+    if (m_status == PLACING_SHIPS) {
+        m_fields[p]->clear();
+        if(p == PLAYER_B) {
+            m_enemyShips.clear();
+        }
+        else {
+            m_myShips.clear();
+        }
+    }
+    m_status = PLACING_SHIPS;
+}
+
 void Sea::add(Player p, Ship* ship)
 {
     if(p == PLAYER_B) {
@@ -94,7 +119,9 @@ void Sea::checkGameOver()
 
 void Sea::allowAdjacentShips(const bool allow_adjacent_ships)
 {
-    m_allow_adjacent_ships = allow_adjacent_ships;
+    m_battle_ships_configuration.setAllowAdjacentShips(allow_adjacent_ships);
+    m_fields[0]->setAllowAdjacentShips(allow_adjacent_ships);
+    m_fields[1]->setAllowAdjacentShips(allow_adjacent_ships);
 }
 
 const Element& Sea::at(Sea::Player player, const Coord& c) const
@@ -153,5 +180,13 @@ const QList<Ship *> Sea::myShips() const
     return m_myShips;
 }
 
+void Sea::setBattleShipsConfiguration(const BattleShipsConfiguration& configuration)
+{
+    m_battle_ships_configuration=configuration;
+    m_fields[0]->setAllowAdjacentShips(configuration.isAllowedAdjacentShips());
+    m_fields[1]->setAllowAdjacentShips(configuration.isAllowedAdjacentShips());
+}
+
+
 #include "sea.moc"
 
