@@ -162,14 +162,9 @@ bool SeaView::setPreview(Sea::Player player, const QPoint& pos)
 {
     QPoint p = pos - m_fields[player]->pos();
     Coord c = m_renderer->toLogical(p);
-    if (Ship* ship = m_delegate->canAddShip(player, c)) {
-        m_fields[player]->setPreview(p, ship);
-        return true;
-    }
-    else {
-        m_fields[player]->cancelPreview();
-        return false;
-    }
+
+    m_fields[player]->setPreview(p);
+    return m_delegate->canAddShip(player, c);
 }
 
 void SeaView::cancelPreview()
@@ -199,6 +194,12 @@ void SeaView::sink(Sea::Player p, Ship* ship)
     m_fields[p]->sink(ship);
 }
 
+void SeaView::setStatus(Sea::Status status)
+{
+    m_fields[0]->setStatus(status);
+    m_fields[1]->setStatus(status);
+}
+
 void SeaView::clear()
 {
     m_fields[0]->clear();
