@@ -16,7 +16,7 @@
 #include <QList>
 
 UIEntity::UIEntity(Sea::Player player, Sea* sea, SeaView* view)
-: Entity(player, view)
+: Entity(player, view, sea->battleShipsConfiguration())
 , m_sea(sea)
 {
 }
@@ -38,7 +38,7 @@ void UIEntity::notifyGameOver(Sea::Player winner)
 
 void UIEntity::start(bool)
 {
-    m_seaview->clear();
+
 }
 
 void UIEntity::hit(Shot* shot)
